Learn R Programming

standardlastprofile (version 1.0.0)

slp_info: Retrieve information on standard load profiles

Description

Information and examples on standard load profiles from the German Association of Energy and Water Industries (BDEW Bundesverband der Energie- und Wasserwirtschaft e.V.)

Usage

slp_info(profile_id, language = c("EN", "DE"))

Value

A list

Arguments

profile_id

load profile identifier, required

language

one of 'EN' (English), 'DE' (German)

Examples

Run this code
slp_info("G5", language = "DE")

# multiple profile IDs are supported
slp_info(c("G0", "G5"))

Run the code above in your browser using DataLab