powered by
Information and examples on standard load profiles from the German Association of Energy and Water Industries (BDEW Bundesverband der Energie- und Wasserwirtschaft e.V.)
slp_info(profile_id, language = c("EN", "DE"))
A list
load profile identifier, required
one of 'EN' (English), 'DE' (German)
slp_info("G5", language = "DE") # multiple profile IDs are supported slp_info(c("G0", "G5"))
Run the code above in your browser using DataLab